@@ -135,3 +135,24 @@ class TestHeterostructure(ut.TestCase):
         h = sc.heterostructure().set_substrate(graphene).add_layer(graphene).add_layer(graphene)
         with self.assertRaises(TypeError):
             h.opt(max_el=4, thetas=[np.arange(0, 10 * sc.DEGREE, 1 * sc.DEGREE)])
+
+    def test_log_does_not_throw(self):
+        # Building the heterostructure
+        graphene = (sc.lattice()
+                    # Default unita are Angstrom coordinates
+                    .set_vectors([2.13, -1.23], [2.13, 1.23])
+                    .add_atom("C", [0, 0], unit=sc.Unit.Crystal)
+                    .add_atom("C", [2 / 3, 2 / 3], unit=sc.Unit.Crystal)
+                    )
+
+        bilayer = (sc.heterostructure()
+                   .set_substrate(graphene)
+                   .add_layer(graphene)
+                   )
+        # Optimisation
+        res_bilayer = bilayer.opt(
+            max_el=12,
+            thetas=np.arange(0, 5 * sc.DEGREE, 0.1 * sc.DEGREE),
+            algorithm="moire",
+            log=True
+        )
\ No newline at end of file
